Welcome to mirror list, hosted at ThFree Co, Russian Federation.

github.com/nextcloud/desktop.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
path: root/test
diff options
context:
space:
mode:
authorCamila <hello@camila.codes>2022-05-12 13:43:03 +0300
committerCamila <hello@camila.codes>2022-05-12 13:47:48 +0300
commite4a0d57bc8abed89425eefd4ffd4e349e35cbc9e (patch)
treeb178d5db20a758919be7db6ca45a0f471e96e8ec /test
parent952eefcf69c65831c1a6a853f3cc15965c1eeb3a (diff)
Do not replace strings in action links coming from the notification api.
Signed-off-by: Camila <hello@camila.codes>
Diffstat (limited to 'test')
-rw-r--r--test/testactivitylistmodel.cpp4
1 files changed, 2 insertions, 2 deletions
diff --git a/test/testactivitylistmodel.cpp b/test/testactivitylistmodel.cpp
index 027a84956..17c5de729 100644
--- a/test/testactivitylistmodel.cpp
+++ b/test/testactivitylistmodel.cpp
@@ -705,10 +705,10 @@ private slots:
// in case total actions is longer than ActivityListModel::maxActionButtons, then a sum of action buttons and action menu entries must be equal to a total of action links
QVERIFY(actionButtonsLinks.size() + actionsLinksContextMenu.size() == actionsLinks.size());
} else {
// in case a total of actions is less or equal to than ActivityListModel::maxActionButtons, then the length of action buttons must be greater than 1 and should contain "Mark as read" button at the end
QVERIFY(actionButtonsLinks.size() > 1);
QVERIFY(actionButtonsLinks[1].value<OCC::ActivityLink>()._label
- == QObject::tr("Mark as read"));
+ == QObject::tr("Dismiss"));
}
} else if ((objectType == QStringLiteral("call"))) {
QVERIFY(
@@ -705,10 +705,10 @@ private slots:
QVERIFY(actionButtonsLinks.size() + actionsLinksContextMenu.size() == actionsLinks.size());
} else {
- // in case a total of actions is less or equal to than ActivityListModel::maxActionButtons, then the length of action buttons must be greater than 1 and should contain "Mark as read" button at the end
+ // in case a total of actions is less or equal to than ActivityListModel::maxActionButtons, then the length of action buttons must be greater than 1 and should contain "Dismiss" button at the end
QVERIFY(actionButtonsLinks.size() > 1);
QVERIFY(actionButtonsLinks[1].value<OCC::ActivityLink>()._label